@@ -16,12 +16,13 @@ import sys
 
 # Third party imports
 from qtpy.QtWidgets import QApplication
-from qtpy.QtCore import Signal, Slot
+from qtpy.QtCore import Signal, Slot, Qt
+from qtpy.QtGui import QKeySequence
 
 # Local imports
 from spyder.config.base import _
 from spyder.config.utils import get_edit_extensions
-from spyder.py3compat import getcwd
+from spyder.utils.misc import getcwd_or_home
 from spyder.utils import icon_manager as ima
 from spyder.utils.qthelpers import create_action, MENU_SEPARATOR
 from spyder.widgets.findinfiles import FindInFilesWidget
@@ -47,22 +48,19 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
         search_text += self.search_text_samples
 
         search_text_regexp = self.get_option('search_text_regexp')
-        include = self.get_option('include')
-        if not include:
-            include = self.include_patterns()
-        include_idx = self.get_option('include_idx', None)
-        include_regexp = self.get_option('include_regexp')
         exclude = self.get_option('exclude')
         exclude_idx = self.get_option('exclude_idx', None)
         exclude_regexp = self.get_option('exclude_regexp')
         in_python_path = self.get_option('in_python_path')
         more_options = self.get_option('more_options')
+        case_sensitive = self.get_option('case_sensitive')
+        path_history = self.get_option('path_history', [])
         FindInFilesWidget.__init__(self, parent,
-                                   search_text, search_text_regexp, search_path,
-                                   include, include_idx, include_regexp,
-                                   exclude, exclude_idx, exclude_regexp,
-                                   supported_encodings,
-                                   in_python_path, more_options)
+                                   search_text, search_text_regexp,
+                                   search_path, exclude, exclude_idx,
+                                   exclude_regexp, supported_encodings,
+                                   in_python_path, more_options,
+                                   case_sensitive, path_history)
         SpyderPluginMixin.__init__(self, parent)
         
         # Initialize plugin
@@ -77,7 +75,19 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
     
     def refreshdir(self):
         """Refresh search directory"""
-        self.find_options.set_directory(getcwd())
+        self.find_options.set_directory(getcwd_or_home())
+
+    def set_project_path(self, path):
+        """Refresh current project path"""
+        self.find_options.set_project_path(path)
+
+    def set_current_opened_file(self, path):
+        """Get path of current opened file in editor"""
+        self.find_options.set_file_path(path)
+
+    def unset_project_path(self):
+        """Refresh current project path"""
+        self.find_options.disable_project_search()
 
     @Slot()
     def findinfiles_callback(self):
@@ -97,23 +107,6 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
         if text:
             self.find()
 
-    @staticmethod
-    def include_patterns():
-        """Generate regex common usage patterns to include section."""
-        # Change special characters, like + and . to convert into valid re
-        clean_exts = []
-        for ext in get_edit_extensions():
-            ext = ext.replace('.', r'\.')
-            ext = ext.replace('+', r'\+')
-            clean_exts.append(ext)
-
-        patterns = [r'|'.join([ext + r'$' for ext in clean_exts if ext]) +
-                    r'|README|INSTALL',
-                    r'\.ipy$|\.pyw?$|\.rst$|\.txt$',
-                    '.',
-                    ]
-        return patterns
-
     #------ SpyderPluginMixin API ---------------------------------------------
     def switch_to_plugin(self):
         """Switch to plugin
@@ -144,12 +137,18 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
         self.edit_goto.connect(self.main.editor.load)
         self.redirect_stdio.connect(self.main.redirect_internalshell_stdio)
         self.main.workingdirectory.refresh_findinfiles.connect(self.refreshdir)
-        
-        findinfiles_action = create_action(self, _("&Find in files"),
+        self.main.projects.sig_project_loaded.connect(self.set_project_path)
+        self.main.projects.sig_project_closed.connect(self.unset_project_path)
+        self.main.editor.open_file_update.connect(self.set_current_opened_file)
+
+        findinfiles_action = create_action(
+                                   self, _("&Find in files"),
                                    icon=ima.icon('findf'),
-                                   triggered=self.findinfiles_callback,
-                                   tip=_("Search text in multiple files"))        
-        
+                                   triggered=self.switch_to_plugin,
+                                   shortcut=QKeySequence(self.shortcut),
+                                   context=Qt.WidgetShortcut,
+                                   tip=_("Search text in multiple files"))
+
         self.main.search_menu_actions += [MENU_SEPARATOR, findinfiles_action]
         self.main.search_toolbar_actions += [MENU_SEPARATOR,
                                              findinfiles_action]
@@ -164,26 +163,25 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
         self.closing_widget()  # stop search thread and clean-up
         options = self.find_options.get_options(all=True)
         if options is not None:
-            search_text, text_re, search_path, \
-            include, include_idx, include_re, \
-            exclude, exclude_idx, exclude_re, \
-            in_python_path, more_options = options
+            (search_text, text_re, search_path,
+             exclude, exclude_idx, exclude_re,
+             in_python_path, more_options, case_sensitive,
+             path_history) = options
             hist_limit = 15
             search_text = search_text[:hist_limit]
             search_path = search_path[:hist_limit]
-            include = include[:hist_limit]
             exclude = exclude[:hist_limit]
+            path_history = path_history[-hist_limit:]
             self.set_option('search_text', search_text)
             self.set_option('search_text_regexp', text_re)
             self.set_option('search_path', search_path)
-            self.set_option('include', include)
-            self.set_option('include_idx', include_idx)
-            self.set_option('include_regexp', include_re)
             self.set_option('exclude', exclude)
             self.set_option('exclude_idx', exclude_idx)
             self.set_option('exclude_regexp', exclude_re)
             self.set_option('in_python_path', in_python_path)
             self.set_option('more_options', more_options)
+            self.set_option('case_sensitive', case_sensitive)
+            self.set_option('path_history', path_history)
         return True
 
 
